.. _all-salt.runners:

==============
runner modules
==============

.. currentmodule:: salt.runners

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    auth
    batch
    cache
    config
    doc
    error
    event
    fileserver
    git_pillar
    http
    jobs
    manage
    match
    mine
    net
    network
    pillar
    pki
    queue
    reactor
    salt
    saltutil
    sdb
    ssh
    state
    survey
    test
    winrepo
